@@ -6,12 +6,12 @@ SpectQuant: \
     for Cardiac Amyloidosis Quantification on SPECT.
 """
 
-__version__ = "0.0.1"
+__version__ = "0.1.2"
 __author__ = "Markus Köfler"
 __all__ = [
     "SUV",
     "TBR",
-    "SegmentVolume",
+    "SegmentVol",
     "UptakeVol",
     "SeptumVol",
     "create_segs"
@@ -20,6 +20,6 @@ __all__ = [
 from .create_segs import create_segs
 from .suv import SUV
 from .tbr import TBR
-from .volume import SegmentVolume
+from .volume import SegmentVol
 from .uptake import UptakeVol
 from .septum import SeptumVol
