@@ -8,9 +8,9 @@ from typing import Optional, List, Dict, Union
 import numpy as np
 import nibabel as nib
     
-import utils
-import morphology
-from create_segs import create_segs
+from spectquant import utils
+from spectquant import morphology
+from spectquant.create_segs import create_segs
 
 
 class SUV:
